==> jc-1.4.0.tar.gz: soot/relations/JBuddyProfiler.h <==
// public class soot.relations.JBuddyProfiler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 20828c9742f04789 soot_relations_JBuddyProfiler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler_H_
#define _JC_soot_relations_JBuddyProfiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler$sub_refs	_jc_soot_relations_JBuddyProfiler$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler$sub_nonrefs	_jc_soot_relations_JBuddyProfiler$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler$refs	_jc_soot_relations_JBuddyProfiler$refs;
typedef struct _jc_soot_relations_JBuddyProfiler$nonrefs	_jc_soot_relations_JBuddyProfiler$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler$object	_jc_soot_relations_JBuddyProfiler$object;

typedef const struct _jc_soot_relations_JBuddyProfiler$vmethods	_jc_soot_relations_JBuddyProfiler$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler$vtable	_jc_soot_relations_JBuddyProfiler$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler$vtype	_jc_soot_relations_JBuddyProfiler$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_relations_JBuddyProfiler$method$finish$012650efe8354b8a(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_soot_relations_JBuddyProfiler$method$printInfo$34eefd1ef54395a7(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *);
extern struct _jc_java_lang_String$object *_jc_soot_relations_JBuddyProfiler$method$stackTrace$961b3766388f9bb7(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *);
extern void _jc_soot_relations_JBuddyProfiler$method$start$a978cd5ea2bb2411(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_soot_relations_JBuddyProfiler$method$start$4c8a73bd382ddcab(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$finish$012650efe8354b8a;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$printInfo$34eefd1ef54395a7;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$stackTrace$961b3766388f9bb7;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$start$a978cd5ea2bb2411;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$start$4c8a73bd382ddcab;

// Static methods
extern struct _jc_soot_relations_JBuddyProfiler$object *_jc_soot_relations_JBuddyProfiler$method$v$a600f8a5fc367856(_jc_env *);

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler$vmethods {
	void	(*finish$012650efe8354b8a)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint);
	void	(*printInfo$34eefd1ef54395a7)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *);
	struct _jc_java_lang_String$object	*(*stackTrace$961b3766388f9bb7)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *);
	void	(*start$a978cd5ea2bb2411)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint);
	void	(*start$4c8a73bd382ddcab)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint, jint);
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler$vmethods	soot_relations_JBuddyProfiler;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler$sub_refs {
	struct _jc_object	*stackTraceToTime;
	struct _jc_java_util_LinkedList$object	*stack;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler$refs {
    _jc_soot_relations_JBuddyProfiler$sub_refs	soot_relations_JBuddyProfiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler$sub_nonrefs	soot_relations_JBuddyProfiler;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler$object {
	_jc_soot_relations_JBuddyProfiler$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler$vtype _jc_soot_relations_JBuddyProfiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler_H_ */

==> jc-1.4.6.tar.gz: soot/relations/JBuddyProfiler.h <==
// public class soot.relations.JBuddyProfiler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 20828c9742f04789 soot_relations_JBuddyProfiler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler_H_
#define _JC_soot_relations_JBuddyProfiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler$sub_refs	_jc_soot_relations_JBuddyProfiler$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler$sub_nonrefs	_jc_soot_relations_JBuddyProfiler$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler$refs	_jc_soot_relations_JBuddyProfiler$refs;
typedef struct _jc_soot_relations_JBuddyProfiler$nonrefs	_jc_soot_relations_JBuddyProfiler$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler$object	_jc_soot_relations_JBuddyProfiler$object;

typedef const struct _jc_soot_relations_JBuddyProfiler$vmethods	_jc_soot_relations_JBuddyProfiler$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler$vtable	_jc_soot_relations_JBuddyProfiler$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler$vtype	_jc_soot_relations_JBuddyProfiler$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_relations_JBuddyProfiler$method$finish$012650efe8354b8a(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_relations_JBuddyProfiler$method$printInfo$34eefd1ef54395a7(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_relations_JBuddyProfiler$method$stackTrace$961b3766388f9bb7(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *) _JC_JCNI_ATTR;
extern void _jc_soot_relations_JBuddyProfiler$method$start$a978cd5ea2bb2411(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_relations_JBuddyProfiler$method$start$4c8a73bd382ddcab(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$finish$012650efe8354b8a;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$printInfo$34eefd1ef54395a7;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$stackTrace$961b3766388f9bb7;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$start$a978cd5ea2bb2411;
extern _jc_method _jc_soot_relations_JBuddyProfiler$method_info$start$4c8a73bd382ddcab;

// Static methods
extern struct _jc_soot_relations_JBuddyProfiler$object *_jc_soot_relations_JBuddyProfiler$method$v$a600f8a5fc367856(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler$vmethods {
	void	(*finish$012650efe8354b8a)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	void	(*printInfo$34eefd1ef54395a7)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*stackTrace$961b3766388f9bb7)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *) _JC_JCNI_ATTR;
	void	(*start$a978cd5ea2bb2411)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	void	(*start$4c8a73bd382ddcab)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler$vmethods	soot_relations_JBuddyProfiler;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler$sub_refs {
	struct _jc_object	*stackTraceToTime;
	struct _jc_java_util_LinkedList$object	*stack;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler$refs {
    _jc_soot_relations_JBuddyProfiler$sub_refs	soot_relations_JBuddyProfiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler$sub_nonrefs	soot_relations_JBuddyProfiler;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler$object {
	_jc_soot_relations_JBuddyProfiler$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler$vtype _jc_soot_relations_JBuddyProfiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler_H_ */
